public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r11-10187] rs6000: Adjust -mdejagnu-cpu to filter out -mtune [PR106345]
@ 2022-08-02  3:56 Kewen Lin
  0 siblings, 0 replies; only message in thread
From: Kewen Lin @ 2022-08-02  3:56 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:ab1d329cb7d5ef19d234c37892c3268f063cf9c5

commit r11-10187-gab1d329cb7d5ef19d234c37892c3268f063cf9c5
Author: Peter Bergner <bergner@linux.ibm.com>
Date:   Mon Jul 25 00:51:44 2022 -0500

    rs6000: Adjust -mdejagnu-cpu to filter out -mtune [PR106345]
    
    As PR106345 shows, when configuring compiler with an explicit
    option --with-tune=<value>, it would cause some test cases to
    fail if their test points are sensitive to tune setting, such
    as: group_ending_nop, loop align etc.  It doesn't help that
    even to specify one explicit -mcpu=.
    
    This patch is to adjust the behavior of -mdejagnu-cpu by
    filtering out all -mcpu= and -mtune= options, then test cases
    would use <cpu> as tune as the one specified by -mdejagnu-cpu.
    
    2022-07-25  Peter Bergner  <bergner@linux.ibm.com>
                Kewen Lin  <linkw@linux.ibm.com>
    
            PR testsuite/106345
    
    gcc/ChangeLog:
    
            * config/rs6000/rs6000.h (DRIVER_SELF_SPECS): Adjust -mdejagnu-cpu
            to filter out all -mtune options.
    
    (cherry picked from commit 75d20d6c84c12bedd65a904e462f02f0b9eb3f77)

Diff:
---
 gcc/config/rs6000/rs6000.h | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/gcc/config/rs6000/rs6000.h b/gcc/config/rs6000/rs6000.h
index 4ca6372435d..3b3dea5114a 100644
--- a/gcc/config/rs6000/rs6000.h
+++ b/gcc/config/rs6000/rs6000.h
@@ -81,12 +81,15 @@
 # define SUBTARGET_DRIVER_SELF_SPECS ""
 #endif
 
-/* Only for use in the testsuite: -mdejagnu-cpu= simply overrides -mcpu=.
+/* Only for use in the testsuite: -mdejagnu-cpu=<value> filters out all
+   -mcpu= as well as -mtune= options then simply adds -mcpu=<value>,
+   while -mdejagnu-tune=<value> filters out all -mtune= options then
+   simply adds -mtune=<value>.
    With older versions of Dejagnu the command line arguments you set in
-   RUNTESTFLAGS override those set in the testcases; with this option,
-   the testcase will always win.  Ditto for -mdejagnu-tune=.  */
+   RUNTESTFLAGS override those set in the testcases; with these options,
+   the testcase will always win.  */
 #define DRIVER_SELF_SPECS \
-  "%{mdejagnu-cpu=*: %<mcpu=* -mcpu=%*}", \
+  "%{mdejagnu-cpu=*: %<mcpu=* %<mtune=* -mcpu=%*}", \
   "%{mdejagnu-tune=*: %<mtune=* -mtune=%*}", \
   "%{mdejagnu-*: %<mdejagnu-*}", \
    SUBTARGET_DRIVER_SELF_SPECS


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-08-02  3:56 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-08-02  3:56 [gcc r11-10187] rs6000: Adjust -mdejagnu-cpu to filter out -mtune [PR106345] Kewen Lin

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).